@@ -29,7 +29,7 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 from six.moves import queue
 
-from os_win._i18n import _, _LI, _LE, _LW
+from os_win._i18n import _
 from os_win import _utils
 from os_win import constants
 from os_win import exceptions
@@ -248,9 +248,9 @@ class ClusterUtils(baseutils.BaseUtils):
                                                      exp_state_after_migr,
                                                      new_host)
                             LOG.warning(
-                                _LW('Cluster group migration completed '
-                                    'successfuly after cancel attempt. '
-                                    'Suppressing timeout exception.'))
+                                'Cluster group migration completed '
+                                'successfuly after cancel attempt. '
+                                'Suppressing timeout exception.')
                             ctxt.reraise = False
                         except exceptions.ClusterGroupMigrationFailed:
                             pass
@@ -307,7 +307,7 @@ class ClusterUtils(baseutils.BaseUtils):
                                         group_name, group_handle,
                                         expected_state,
                                         timeout=None):
-        LOG.info(_LI("Canceling cluster group '%s' migration"), group_name)
+        LOG.info("Canceling cluster group '%s' migration", group_name)
         try:
             cancel_finished = (
                 self._clusapi_utils.cancel_cluster_group_operation(
@@ -335,10 +335,10 @@ class ClusterUtils(baseutils.BaseUtils):
                     expected_state,
                     timeout=timeout)
             except Exception:
-                LOG.exception(_LE("Failed to cancel cluster group migration."))
+                LOG.exception("Failed to cancel cluster group migration.")
                 raise exceptions.JobTerminateFailed()
 
-        LOG.info(_LI("Cluster group migration canceled."))
+        LOG.info("Cluster group migration canceled.")
 
     def _is_migration_queued(self, group_status_info):
         return bool(
@@ -394,7 +394,7 @@ class ClusterUtils(baseutils.BaseUtils):
             if not migration_pending:
                 return
 
-        LOG.error(_LE("Cluster group migration timed out."))
+        LOG.error("Cluster group migration timed out.")
         raise exceptions.ClusterGroupMigrationTimeOut(
             group_name=group_name,
             time_elapsed=time.time() - time_start)
@@ -438,7 +438,8 @@ class ClusterUtils(baseutils.BaseUtils):
         state_info['status_info'] = status_info
         return state_info
 
-    def monitor_vm_failover(self, callback):
+    def monitor_vm_failover(self, callback,
+                            event_timeout_ms=_WMI_EVENT_TIMEOUT_MS):
         """Creates a monitor to check for new WMI MSCluster_Resource
 
         events.
@@ -450,15 +451,19 @@ class ClusterUtils(baseutils.BaseUtils):
         Any event object caught will then be processed.
         """
 
+        # TODO(lpetrut): mark this method as private once compute-hyperv
+        # stops using it. We should also remove the instance '_watcher'
+        # attribute since we end up spawning unused event listeners.
+
         vm_name = None
         new_host = None
         try:
             # wait for new event for _WMI_EVENT_TIMEOUT_MS miliseconds.
             if patcher.is_monkey_patched('thread'):
                 wmi_object = tpool.execute(self._watcher,
-                                           self._WMI_EVENT_TIMEOUT_MS)
+                                           event_timeout_ms)
             else:
-                wmi_object = self._watcher(self._WMI_EVENT_TIMEOUT_MS)
+                wmi_object = self._watcher(event_timeout_ms)
 
             old_host = wmi_object.previous.OwnerNode
             new_host = wmi_object.OwnerNode
@@ -475,10 +480,29 @@ class ClusterUtils(baseutils.BaseUtils):
                     callback(vm_name, old_host, new_host)
                 except Exception:
                     LOG.exception(
-                        _LE("Exception during failover callback."))
+                        "Exception during failover callback.")
         except exceptions.x_wmi_timed_out:
             pass
 
+    def get_vm_owner_change_listener(self):
+        def listener(callback):
+            while True:
+                # We avoid setting an infinite timeout in order to let
+                # the process gracefully stop. Note that the os-win WMI
+                # event listeners are meant to be used as long running
+                # daemons, so no stop API is provided ATM.
+                try:
+                    self.monitor_vm_failover(
+                        callback,
+                        constants.DEFAULT_WMI_EVENT_TIMEOUT_MS)
+                except Exception:
+                    LOG.exception("The VM cluster group owner change "
+                                  "event listener encountered an "
+                                  "unexpected exception.")
+                    time.sleep(constants.DEFAULT_WMI_EVENT_TIMEOUT_MS / 1000)
+
+        return listener
+
 
 # At the moment, those event listeners are not meant to be used outside
 # os-win, mostly because of the underlying API limitations.
@@ -567,8 +591,8 @@ class _ClusterEventListener(object):
             except Exception:
                 if self._running:
                     LOG.exception(
-                        _LE("Unexpected exception in event listener loop. "
-                            "The cluster event listener will now close."))
+                        "Unexpected exception in event listener loop. "
+                        "The cluster event listener will now close.")
                     self._signal_stopped()
 
     def _process_event(self, event):
