@@ -17,7 +17,7 @@ import platform
 
 from oslo_log import log as logging
 
-from os_win._i18n import _, _LE
+from os_win._i18n import _
 from os_win import exceptions
 from os_win.utils import _wqlutils
 from os_win.utils.compute import migrationutils
@@ -42,7 +42,7 @@ class LiveMigrationUtils(migrationutils.MigrationUtils):
             return self._get_wmi_obj(self._wmi_namespace % host,
                                      compatibility_mode=True)
         except exceptions.x_wmi as ex:
-            LOG.exception(_LE('Get version 2 connection error'))
+            LOG.exception('Get version 2 connection error')
             if ex.com_error.hresult == -2147217394:
                 msg = (_('Live migration is not supported on target host "%s"')
                        % host)
