@@ -28,10 +28,9 @@ from eventlet import patcher
 from eventlet import tpool
 from oslo_log import log as logging
 from oslo_utils import uuidutils
-import six
 from six.moves import range  # noqa
 
-from os_win._i18n import _, _LE, _LW
+from os_win._i18n import _
 from os_win import _utils
 from os_win import constants
 from os_win import exceptions
@@ -129,14 +128,13 @@ class VMUtils(baseutils.BaseUtilsVirt):
     }
 
     _DEFAULT_EVENT_CHECK_TIMEFRAME = 60  # seconds
-    _DEFAULT_EVENT_TIMEOUT_MS = 2000
 
     def __init__(self, host='.'):
         super(VMUtils, self).__init__(host)
         self._jobutils = jobutils.JobUtils(host)
         self._pathutils = pathutils.PathUtils()
         self._enabled_states_map = {v: k for k, v in
-                                    six.iteritems(self._vm_power_states_map)}
+                                    self._vm_power_states_map.items()}
 
     def list_instance_notes(self):
         instance_notes = []
@@ -501,8 +499,8 @@ class VMUtils(baseutils.BaseUtilsVirt):
             # Add the new vhd object as a virtual hard disk to the vm.
             self._jobutils.add_virt_resource(res, vm)
         except Exception:
-            LOG.exception(_LE("Failed to attach disk image %(disk_path)s "
-                              "to vm %(vm_name)s. Reverting attachment."),
+            LOG.exception("Failed to attach disk image %(disk_path)s "
+                          "to vm %(vm_name)s. Reverting attachment.",
                           dict(disk_path=path, vm_name=vm_name))
 
             drive = self._get_wmi_obj(drive_path)
@@ -609,9 +607,9 @@ class VMUtils(baseutils.BaseUtilsVirt):
                 disk_found = True
                 break
         if not disk_found:
-            LOG.warning(_LW('Disk not found on controller '
-                            '"%(controller_path)s" with '
-                            'address "%(address)s"'),
+            LOG.warning('Disk not found on controller '
+                        '"%(controller_path)s" with '
+                        'address "%(address)s"',
                         {'controller_path': controller_path,
                          'address': address})
 
@@ -907,7 +905,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     def get_vm_power_state_change_listener(
             self, timeframe=_DEFAULT_EVENT_CHECK_TIMEFRAME,
-            event_timeout=_DEFAULT_EVENT_TIMEOUT_MS,
+            event_timeout=constants.DEFAULT_WMI_EVENT_TIMEOUT_MS,
             filtered_states=None, get_handler=False):
         field = self._VM_ENABLED_STATE_PROP
         query = self._get_event_wql_query(cls=self._COMPUTER_SYSTEM_CLASS,
@@ -942,10 +940,10 @@ class VMUtils(baseutils.BaseUtilsVirt):
                     try:
                         callback(vm_name, vm_power_state)
                     except Exception:
-                        err_msg = _LE("Executing VM power state change event "
-                                      "callback failed. "
-                                      "VM name: %(vm_name)s, "
-                                      "VM power state: %(vm_power_state)s.")
+                        err_msg = ("Executing VM power state change "
+                                   "event callback failed. "
+                                   "VM name: %(vm_name)s, "
+                                   "VM power state: %(vm_power_state)s.")
                         LOG.exception(err_msg,
                                       dict(vm_name=vm_name,
                                            vm_power_state=vm_power_state))
@@ -953,8 +951,8 @@ class VMUtils(baseutils.BaseUtilsVirt):
                     pass
                 except Exception:
                     LOG.exception(
-                        _LE("The VM power state change event listener "
-                            "encountered an unexpected exception."))
+                        "The VM power state change event listener "
+                        "encountered an unexpected exception.")
                     time.sleep(event_timeout / 1000)
 
         return _handle_events if get_handler else listener
