@@ -26,7 +26,7 @@ from eventlet import tpool
 from oslo_utils import units
 import six
 
-from os_win._i18n import _, _LE
+from os_win._i18n import _
 from os_win import constants
 from os_win import exceptions
 from os_win.utils import _wqlutils
@@ -233,8 +233,7 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
         vnic_settings = self._conn.Msvm_SyntheticEthernetPortSettingData(
             ElementName=vnic_name)
         if not vnic_settings:
-            raise exceptions.HyperVException(
-                message=_('Vnic not found: %s') % vnic_name)
+            raise exceptions.HyperVvNicNotFound(vnic_name=vnic_name)
         return vnic_settings[0]
 
     def get_vnic_event_listener(self, event_type):
@@ -369,8 +368,8 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
             self._jobutils.add_virt_feature(new_port_profile, port_alloc)
         except Exception as ex:
             raise exceptions.HyperVException(
-                _LE('Unable to set port profile settings %(port_profile)s '
-                    'for port %(port)s. Error: %(error)s') %
+                'Unable to set port profile settings %(port_profile)s '
+                'for port %(port)s. Error: %(error)s' %
                 dict(port_profile=new_port_profile, port=port_alloc, error=ex))
 
     def set_vswitch_port_vlan_id(self, vlan_id=None, switch_port_name=None,
@@ -830,8 +829,8 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
                 raise exceptions.InvalidParameterValue(
                     param_name="qos_rule", param_value=qos_rule)
             raise exceptions.HyperVException(
-                _LE('Unable to set qos rule %(qos_rule)s for port %(port)s. '
-                    'Error: %(error)s') %
+                'Unable to set qos rule %(qos_rule)s for port %(port)s. '
+                'Error: %(error)s' %
                 dict(qos_rule=qos_rule, port=port_alloc, error=ex))
 
     def remove_port_qos_rule(self, port_id):
