@@ -23,7 +23,6 @@ import time
 
 from oslo_log import log as logging
 
-from os_win._i18n import _LI, _LE
 from os_win import _utils
 from os_win import constants
 from os_win import exceptions
@@ -136,8 +135,8 @@ class ISCSIInitiatorUtils(object):
                                        ctypes.byref(buff))
             return buff.value
         except exceptions.ISCSIInitiatorAPIException as ex:
-            LOG.info(_LI("The ISCSI initiator node name can't be found. "
-                         "Choosing the default one. Exception: %s"), ex)
+            LOG.info("The ISCSI initiator node name can't be found. "
+                     "Choosing the default one. Exception: %s", ex)
             return "%s:%s" % (self._MS_IQN_PREFIX, socket.getfqdn().lower())
 
     @ensure_buff_and_retrieve_items(
@@ -253,7 +252,7 @@ class ISCSIInitiatorUtils(object):
             # fail to locate it, in which case some retries will be performed.
             (device_number,
              device_path) = self.ensure_lun_available(target_name, target_lun,
-                                                      retry_attempts=10,
+                                                      rescan_attempts=10,
                                                       retry_interval=0.1,
                                                       rescan_disks=False)
         except exceptions.ISCSILunNotAvailable:
@@ -397,12 +396,12 @@ class ISCSIInitiatorUtils(object):
             self.ensure_lun_available(target_iqn, target_lun, rescan_attempts)
 
     def ensure_lun_available(self, target_iqn, target_lun,
-                             retry_attempts=_DEFAULT_RESCAN_ATTEMPTS,
+                             rescan_attempts=_DEFAULT_RESCAN_ATTEMPTS,
                              retry_interval=0,
                              rescan_disks=True):
         # This method should be called only after the iSCSI
         # target has already been logged in.
-        for attempt in range(retry_attempts + 1):
+        for attempt in range(rescan_attempts + 1):
             sessions = self._get_iscsi_target_sessions(target_iqn)
             for session in sessions:
                 try:
@@ -418,13 +417,13 @@ class ISCSIInitiatorUtils(object):
                     if device_path and device_number not in (None, -1):
                         return device_number, device_path
                 except exceptions.ISCSIInitiatorAPIException:
-                    err_msg = _LE("Could not find lun %(target_lun)s "
-                                  "for iSCSI target %(target_iqn)s.")
+                    err_msg = ("Could not find lun %(target_lun)s  "
+                               "for iSCSI target %(target_iqn)s.")
                     LOG.exception(err_msg,
                                   dict(target_lun=target_lun,
                                        target_iqn=target_iqn))
                     continue
-            if attempt <= retry_attempts:
+            if attempt <= rescan_attempts:
                 if retry_interval:
                     time.sleep(retry_interval)
                 if rescan_disks:
