@@ -17,13 +17,14 @@
 import ctypes
 import sys
 
-if sys.platform == 'win32':
-    kernel32 = ctypes.windll.kernel32
-
 from oslo_log import log as logging
 
+from os_win import _utils
 from os_win import exceptions
 
+if sys.platform == 'win32':
+    kernel32 = ctypes.windll.kernel32
+
 LOG = logging.getLogger(__name__)
 
 FORMAT_MESSAGE_FROM_SYSTEM = 0x00001000
@@ -36,7 +37,19 @@ class Win32Utils(object):
         self._kernel32_lib_func_opts = dict(error_on_nonzero_ret_val=False,
                                             ret_val_is_err_code=False)
 
-    def run_and_check_output(self, func, *args, **kwargs):
+    def run_and_check_output(self, *args, **kwargs):
+        eventlet_nonblocking_mode = kwargs.pop(
+            'eventlet_nonblocking_mode', True)
+
+        if eventlet_nonblocking_mode:
+            # We have to make sure that the invoked function as well as the
+            # subsequent error handling are performed within the same thread.
+            return _utils.avoid_blocking_call(
+                self._run_and_check_output, *args, **kwargs)
+        else:
+            return self._run_and_check_output(*args, **kwargs)
+
+    def _run_and_check_output(self, func, *args, **kwargs):
         """Convenience helper method for running Win32 API methods."""
         kernel32_lib_func = kwargs.pop('kernel32_lib_func', False)
         if kernel32_lib_func:
@@ -65,7 +78,7 @@ class Win32Utils(object):
         ret_val = func(*args, **kwargs)
 
         func_failed = (error_on_nonzero_ret_val and ret_val) or (
-                       ret_val in error_ret_vals)
+            ret_val in error_ret_vals)
 
         if func_failed:
             error_code = (ret_val
@@ -115,3 +128,10 @@ class Win32Utils(object):
             return ctypes.c_uint(com_error.excepinfo[5]).value
         except Exception:
             LOG.debug("Unable to retrieve COM error hresult: %s", com_error)
+
+    def local_free(self, handle):
+        try:
+            self._run_and_check_output(kernel32.LocalFree, handle)
+        except exceptions.Win32Exception:
+            LOG.exception("Could not deallocate memory. "
+                          "There could be a memory leak.")
